==> jc-1.4.0.tar.gz: org/xml/sax/SAXNotRecognizedException.h <==
// public class org.xml.sax.SAXNotRecognizedException

// class file dependencies
// @dep_class c5feb325780a6cd7 java_lang_Exception
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 3be5c3c4fdd59a1e java_lang_Throwable
// @dep_class c045a3d7d4ce55f1 org_xml_sax_SAXException
// @dep_class 367865d8b307be5f org_xml_sax_SAXNotRecognizedException

// header file dependencies
// @dep_header org_xml_sax_SAXException

#include "org/xml/sax/SAXException.h"

#ifndef _JC_org_xml_sax_SAXNotRecognizedException_H_
#define _JC_org_xml_sax_SAXNotRecognizedException_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_org_xml_sax_SAXNotRecognizedException$sub_refs	_jc_org_xml_sax_SAXNotRecognizedException$sub_refs;
typedef struct _jc_org_xml_sax_SAXNotRecognizedException$sub_nonrefs	_jc_org_xml_sax_SAXNotRecognizedException$sub_nonrefs;
typedef struct _jc_org_xml_sax_SAXNotRecognizedException$refs	_jc_org_xml_sax_SAXNotRecognizedException$refs;
typedef struct _jc_org_xml_sax_SAXNotRecognizedException$nonrefs	_jc_org_xml_sax_SAXNotRecognizedException$nonrefs;
typedef struct _jc_org_xml_sax_SAXNotRecognizedException$object	_jc_org_xml_sax_SAXNotRecognizedException$object;

typedef const struct _jc_org_xml_sax_SAXNotRecognizedException$vmethods	_jc_org_xml_sax_SAXNotRecognizedException$vmethods;
typedef const struct _jc_org_xml_sax_SAXNotRecognizedException$vtable	_jc_org_xml_sax_SAXNotRecognizedException$vtable;
typedef const struct _jc_org_xml_sax_SAXNotRecognizedException$vtype	_jc_org_xml_sax_SAXNotRecognizedException$vtype;

// Constructors
extern void _jc_org_xml_sax_SAXNotRecognizedException$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_org_xml_sax_SAXNotRecognizedException$object *);
extern void _jc_org_xml_sax_SAXNotRecognizedException$method$_init$c31b894660454d13(_jc_env *, struct _jc_org_xml_sax_SAXNotRecognizedException$object *, struct _jc_java_lang_String$object *);

// Virtual methods structure
struct _jc_org_xml_sax_SAXNotRecognizedException$vmethods {
};

// Vtable
struct _jc_org_xml_sax_SAXNotRecognizedException$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Throwable$vmethods	java_lang_Throwable;
	_jc_java_lang_Exception$vmethods	java_lang_Exception;
	_jc_org_xml_sax_SAXException$vmethods	org_xml_sax_SAXException;
	_jc_org_xml_sax_SAXNotRecognizedException$vmethods	org_xml_sax_SAXNotRecognizedException;
};

// Vtype
struct _jc_org_xml_sax_SAXNotRecognizedException$vtype {
	_jc_type			type;
	_jc_org_xml_sax_SAXNotRecognizedException$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_org_xml_sax_SAXNotRecognizedException$sub_refs {
};

// Reference instance fields (object)
struct _jc_org_xml_sax_SAXNotRecognizedException$refs {
    _jc_org_xml_sax_SAXNotRecognizedException$sub_refs	org_xml_sax_SAXNotRecognizedException;
    _jc_org_xml_sax_SAXException$sub_refs	org_xml_sax_SAXException;
    _jc_java_lang_Exception$sub_refs	java_lang_Exception;
    _jc_java_lang_Throwable$sub_refs	java_lang_Throwable;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_org_xml_sax_SAXNotRecognizedException$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_org_xml_sax_SAXNotRecognizedException$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Throwable$sub_nonrefs	java_lang_Throwable;
    _jc_java_lang_Exception$sub_nonrefs	java_lang_Exception;
    _jc_org_xml_sax_SAXException$sub_nonrefs	org_xml_sax_SAXException;
    _jc_org_xml_sax_SAXNotRecognizedException$sub_nonrefs	org_xml_sax_SAXNotRecognizedException;
};

// Object instance structure
struct _jc_org_xml_sax_SAXNotRecognizedException$object {
	_jc_org_xml_sax_SAXNotRecognizedException$refs	refs[0];
	_jc_word		lockword;
	_jc_org_xml_sax_SAXNotRecognizedException$vtype	*vtype;
	_jc_org_xml_sax_SAXNotRecognizedException$nonrefs	nonrefs;
};

// Type structure
extern _jc_org_xml_sax_SAXNotRecognizedException$vtype _jc_org_xml_sax_SAXNotRecognizedException$type;

// Array types class info structures
_JC_DECL_ARRAYS(org_xml_sax_SAXNotRecognizedException, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_org_xml_sax_SAXNotRecognizedException$class_object;

#endif	/* _JC_org_xml_sax_SAXNotRecognizedException_H_ */

==> jc-1.4.6.tar.gz: org/xml/sax/SAXNotRecognizedException.h <==
// public class org.xml.sax.SAXNotRecognizedException

// class file dependencies
// @dep_class c5feb325780a6cd7 java_lang_Exception
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 3be5c3c4fdd59a1e java_lang_Throwable
// @dep_class c045a3d7d4ce55f1 org_xml_sax_SAXException
// @dep_class 367865d8b307be5f org_xml_sax_SAXNotRecognizedException

// header file dependencies
// @dep_header org_xml_sax_SAXException

#include "org/xml/sax/SAXException.h"

#ifndef _JC_org_xml_sax_SAXNotRecognizedException_H_
#define _JC_org_xml_sax_SAXNotRecognizedException_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_org_xml_sax_SAXNotRecognizedException$sub_refs	_jc_org_xml_sax_SAXNotRecognizedException$sub_refs;
typedef struct _jc_org_xml_sax_SAXNotRecognizedException$sub_nonrefs	_jc_org_xml_sax_SAXNotRecognizedException$sub_nonrefs;
typedef struct _jc_org_xml_sax_SAXNotRecognizedException$refs	_jc_org_xml_sax_SAXNotRecognizedException$refs;
typedef struct _jc_org_xml_sax_SAXNotRecognizedException$nonrefs	_jc_org_xml_sax_SAXNotRecognizedException$nonrefs;
typedef struct _jc_org_xml_sax_SAXNotRecognizedException$object	_jc_org_xml_sax_SAXNotRecognizedException$object;

typedef const struct _jc_org_xml_sax_SAXNotRecognizedException$vmethods	_jc_org_xml_sax_SAXNotRecognizedException$vmethods;
typedef const struct _jc_org_xml_sax_SAXNotRecognizedException$vtable	_jc_org_xml_sax_SAXNotRecognizedException$vtable;
typedef const struct _jc_org_xml_sax_SAXNotRecognizedException$vtype	_jc_org_xml_sax_SAXNotRecognizedException$vtype;

// Constructors
extern void _jc_org_xml_sax_SAXNotRecognizedException$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_org_xml_sax_SAXNotRecognizedException$object *) _JC_JCNI_ATTR;
extern void _jc_org_xml_sax_SAXNotRecognizedException$method$_init$c31b894660454d13(_jc_env *, struct _jc_org_xml_sax_SAXNotRecognizedException$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_org_xml_sax_SAXNotRecognizedException$vmethods {
};

// Vtable
struct _jc_org_xml_sax_SAXNotRecognizedException$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Throwable$vmethods	java_lang_Throwable;
	_jc_java_lang_Exception$vmethods	java_lang_Exception;
	_jc_org_xml_sax_SAXException$vmethods	org_xml_sax_SAXException;
	_jc_org_xml_sax_SAXNotRecognizedException$vmethods	org_xml_sax_SAXNotRecognizedException;
};

// Vtype
struct _jc_org_xml_sax_SAXNotRecognizedException$vtype {
	_jc_type			type;
	_jc_org_xml_sax_SAXNotRecognizedException$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_org_xml_sax_SAXNotRecognizedException$sub_refs {
};

// Reference instance fields (object)
struct _jc_org_xml_sax_SAXNotRecognizedException$refs {
    _jc_org_xml_sax_SAXNotRecognizedException$sub_refs	org_xml_sax_SAXNotRecognizedException;
    _jc_org_xml_sax_SAXException$sub_refs	org_xml_sax_SAXException;
    _jc_java_lang_Exception$sub_refs	java_lang_Exception;
    _jc_java_lang_Throwable$sub_refs	java_lang_Throwable;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_org_xml_sax_SAXNotRecognizedException$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_org_xml_sax_SAXNotRecognizedException$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Throwable$sub_nonrefs	java_lang_Throwable;
    _jc_java_lang_Exception$sub_nonrefs	java_lang_Exception;
    _jc_org_xml_sax_SAXException$sub_nonrefs	org_xml_sax_SAXException;
    _jc_org_xml_sax_SAXNotRecognizedException$sub_nonrefs	org_xml_sax_SAXNotRecognizedException;
};

// Object instance structure
struct _jc_org_xml_sax_SAXNotRecognizedException$object {
	_jc_org_xml_sax_SAXNotRecognizedException$refs	refs[0];
	_jc_word		lockword;
	_jc_org_xml_sax_SAXNotRecognizedException$vtype	*vtype;
	_jc_org_xml_sax_SAXNotRecognizedException$nonrefs	nonrefs;
};

// Type structure
extern _jc_org_xml_sax_SAXNotRecognizedException$vtype _jc_org_xml_sax_SAXNotRecognizedException$type;

// Array types class info structures
_JC_DECL_ARRAYS(org_xml_sax_SAXNotRecognizedException, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_org_xml_sax_SAXNotRecognizedException$class_object;

#endif	/* _JC_org_xml_sax_SAXNotRecognizedException_H_ */
